/* Space out content a bit */
body {
  padding-top: 20px;
  padding-bottom: 20px;
}

/* Customize container */
@media (min-width: 768px) {
  .container {
    max-width: 800px;
  }
}
.container-narrow > hr {
  margin: 30px 0;
}

.jumbotron h1 {
  text-align: center;
}

/* Responsive: Portrait tablets and up */
@media screen and (min-width: 768px) {
  /* Remove the padding we set earlier */
  .header,
  .marketing,
  .footer {
    padding-right: 0;
    padding-left: 0;
  }

  /* Remove the bottom border on the jumbotron for visual effect */
  .jumbotron {
    border-bottom: 0;
  }
}