[ng\:cloak], [ng-cloak], [data-ng-cloak], [x-ng-cloak], .ng-cloak, .x-ng-cloak {
  display: none !important;
}

.dates {
    margin-top: 30px;
    font-size: 14pt;
}

.dates td {
    padding-right: 15px;
    padding-bottom: 15px;
}

.date-title {
    font-weight: bold;
}

.habit-name {
    padding: 5px;
    cursor: pointer;
}

.completed .habit-name {
    background-color: #80CC80;
}

.uncompleted .habit-name {
    background-color: #FFD699;
}

.configuration tr {
    padding-bottom: 10px;
}